@@ -1,6 +1,6 @@
 import re
 
-from datetime import datetime
+from datetime import datetime, timedelta
 from scrapy import log
 from scrapy.contrib.loader import ItemLoader
 from scrapy.contrib.loader.processor import Compose, MapCompose, TakeFirst
@@ -123,7 +123,8 @@ class MatchEndDate(object):
                     pass
                 else:
                     local_name = value.xpath('local-name()')[0].extract()
-                    return IntermediateValue(local_name, val, text, context, value,
+                    return IntermediateValue(
+                        local_name, val, text, context, value,
                         start_date=start_date, end_date=end_date, instant=instant)
 
         return None
@@ -163,6 +164,13 @@ def get_amend(values):
     return False
 
 
+def get_symbol(values):
+    if values:
+        symbols = map(lambda s: s.strip(), values[0].split(','))
+        return '/'.join(symbols)
+    return False
+
+
 def imd_max(imd_values):
     if imd_values:
         imd_value = max(imd_values)
@@ -375,7 +383,7 @@ class ReportItemLoader(XmlXPathItemLoader):
     default_output_processor = TakeFirst()
 
     symbol_in = MapCompose(ExtractText(), unicode.upper)
-    symbol_out = TakeFirst()
+    symbol_out = Compose(get_symbol)
 
     amend_in = MapCompose(ExtractText(), str_to_bool)
     amend_out = Compose(get_amend)
@@ -437,6 +445,7 @@ class ReportItemLoader(XmlXPathItemLoader):
 
         symbol = self._get_symbol()
         end_date = self._get_doc_end_date()
+        fiscal_year = self._get_doc_fiscal_year()
         doc_type = self._get_doc_type()
 
         # ignore document that is not 10-Q or 10-K
@@ -463,15 +472,19 @@ class ReportItemLoader(XmlXPathItemLoader):
         else:
             self.add_xpath('amend', '//dei:AmendmentFlag')
 
+        if doc_type == '10-K':
+            period_focus = 'FY'
+        else:
+            period_focus = self._get_period_focus(end_date)
+
+        if not fiscal_year and period_focus:
+            fiscal_year = self._guess_fiscal_year(end_date, period_focus)
+
+        self.add_value('period_focus', period_focus)
+        self.add_value('fiscal_year', fiscal_year)
         self.add_value('end_date', end_date)
         self.add_value('doc_type', doc_type)
 
-        if doc_type == '10-K':
-            self.add_value('period_focus', 'FY')
-        elif not self.add_xpath('period_focus', '//dei:DocumentFiscalPeriodFocus'):
-            period_focus = self._get_period_focus(end_date)
-            self.add_value('period_focus', period_focus)
-
         self.add_xpaths('revenues', [
             '//us-gaap:SalesRevenueNet',
             '//us-gaap:Revenues',
@@ -602,6 +615,48 @@ class ReportItemLoader(XmlXPathItemLoader):
         except IndexError:
             return None
 
+    def _get_doc_fiscal_year(self):
+        try:
+            fiscal_year = self.selector.xpath('//dei:DocumentFiscalYearFocus/text()')[0].extract()
+            return int(fiscal_year)
+        except (IndexError, ValueError):
+            return None
+
+    def _guess_fiscal_year(self, end_date, period_focus):
+        # Guess fiscal_year based on document end_date and period_focus
+        date = datetime.strptime(end_date, DATE_FORMAT)
+        month_ranges = {
+            'Q1': (2, 3, 4),
+            'Q2': (5, 6, 7),
+            'Q3': (8, 9, 10),
+            'FY': (11, 12, 1)
+        }
+        month_range = month_ranges.get(period_focus)
+
+        # Case 1: release Q1 around March, Q2 around June, ...
+        # This is what most companies do
+        if date.month in month_range:
+            if period_focus == 'FY' and date.month == 1:
+                return date.year - 1
+            return date.year
+
+        # How many days left before 10-K's release?
+        days_left_table = {
+            'Q1': 270,
+            'Q2': 180,
+            'Q3': 90,
+            'FY': 0
+        }
+        days_left = days_left_table.get(period_focus)
+
+        # Other cases, assume end_date.year of its FY report equals to
+        # its fiscal_year
+        if days_left is not None:
+            fy_date = date + timedelta(days=days_left)
+            return fy_date.year
+
+        return None
+
     def _get_doc_end_date(self):
         # the document end date could come from URL or document content
         # we need to guess which one is correct
@@ -630,6 +685,11 @@ class ReportItemLoader(XmlXPathItemLoader):
             return None
 
     def _get_period_focus(self, doc_end_date):
+        try:
+            return self.selector.xpath('//dei:DocumentFiscalPeriodFocus/text()')[0].extract().upper()
+        except IndexError:
+            pass
+
         try:
             doc_yr = doc_end_date.split('-')[0]
             yr_end_date = self.selector.xpath('//dei:CurrentFiscalYearEndDate/text()')[0].extract()
